@@ -1,21 +1,20 @@
 use bevy::{
-    app::{App, ScheduleRunnerSettings, AppExit, EventWriter, CoreStage},
-    core::Time,
-    ecs::prelude::*,
-    MinimalPlugins,
+    app::{AppExit, ScheduleRunnerSettings},
+    log::LogPlugin,
+    prelude::*,
 };
 
 use serde::{Deserialize, Serialize};
 
 use bevy_networking_turbulence::{
-    ConnectionChannelsBuilder, MessageChannelMode, MessageChannelSettings,
-    NetworkResource, NetworkingPlugin, MessageFlushingStrategy,
+    ConnectionChannelsBuilder, MessageChannelMode, MessageChannelSettings, MessageFlushingStrategy,
+    NetworkResource, NetworkingPlugin,
 };
 
 use std::{net::SocketAddr, time::Duration};
 
 mod utils;
-use utils::{MessageCoalescingArgs as Args, parse_message_coalescing_args};
+use utils::{parse_message_coalescing_args, MessageCoalescingArgs as Args};
 
 const SERVER_PORT: u16 = 14191;
 const NUM_PINGS: usize = 100;
@@ -33,25 +32,13 @@ type TTL = Option<f64>;
 type Ticks = usize;
 
 fn main() {
-    cfg_if::cfg_if! {
-        if #[cfg(target_arch = "wasm32")] {
-            std::panic::set_hook(Box::new(console_error_panic_hook::hook));
-            console_log::init_with_level(log::Level::Debug).expect("cannot initialize console_log");
-        }
-        else {
-            simple_logger::SimpleLogger::from_env()
-            .init()
-            .expect("A logger was already initialized");
-        }
-    }
-
     let args = parse_message_coalescing_args();
     let mut net_plugin = NetworkingPlugin::default();
     if args.manual_flush {
         net_plugin.message_flushing_strategy = MessageFlushingStrategy::Never;
     }
 
-    let mut app = App::build();
+    let mut app = App::new();
     app
         // minimal plugins necessary for timers + headless loop
         .insert_resource(ScheduleRunnerSettings::run_loop(Duration::from_secs_f64(
@@ -61,6 +48,7 @@ fn main() {
         .insert_resource::<TTL>(None)
         .insert_resource(PingPongCounter::default())
         .add_plugins(MinimalPlugins)
+        .add_plugin(LogPlugin)
         // The NetworkingPlugin
         .add_plugin(net_plugin)
         // Our networking
@@ -70,8 +58,7 @@ fn main() {
         .add_system(tick.system())
         .add_system(send_messages.system())
         .add_system(handle_messages.system())
-        .add_system(ttl_system.system())
-        ;
+        .add_system(ttl_system.system());
     if parse_message_coalescing_args().manual_flush {
         app.add_system_to_stage(CoreStage::PostUpdate, flush_channels.system());
     }
@@ -86,7 +73,7 @@ enum NetMsg {
 
 const NETMSG_SETTINGS: MessageChannelSettings = MessageChannelSettings {
     channel: 0,
-    channel_mode: MessageChannelMode::Unreliable,   
+    channel_mode: MessageChannelMode::Unreliable,
     // The buffer size for the mpsc channel of messages that transports messages of this type to /
     // from the network task.
     message_buffer_size: NUM_PINGS,
@@ -129,29 +116,43 @@ fn startup(mut net: ResMut<NetworkResource>, args: Res<Args>) {
 
     #[cfg(not(target_arch = "wasm32"))]
     if args.is_server {
-        log::info!("Starting server");
+        info!("Starting server");
         net.listen(server_address, None, None);
     }
     if !args.is_server {
-        log::info!("Starting client");
+        info!("Starting client");
         net.connect(server_address);
     }
 }
 
-fn ttl_system(mut ttl: ResMut<TTL>, mut exit: EventWriter<AppExit>, time: Res<Time>, net: Res<NetworkResource>, ppc: Res<PingPongCounter>, args: Res<Args>) {
+fn ttl_system(
+    mut ttl: ResMut<TTL>,
+    mut exit: EventWriter<AppExit>,
+    time: Res<Time>,
+    net: Res<NetworkResource>,
+    ppc: Res<PingPongCounter>,
+    args: Res<Args>,
+) {
     match *ttl {
-        None => {},
+        None => {}
         Some(secs) => {
             let new_secs = secs - time.delta_seconds_f64();
             if new_secs <= 0.0 {
                 // dump some stats and exit
-                log::info!("Final stats, is_server: {:?}, flushing mode: {}", args.is_server, 
-                    if args.manual_flush {"--manual-flush"} else {"--auto-flush"});
-                log::info!("{:?}", *ppc);
+                info!(
+                    "Final stats, is_server: {:?}, flushing mode: {}",
+                    args.is_server,
+                    if args.manual_flush {
+                        "--manual-flush"
+                    } else {
+                        "--auto-flush"
+                    }
+                );
+                info!("{:?}", *ppc);
                 for (handle, connection) in net.connections.iter() {
-                    log::info!("{:?} [h:{}]", connection.stats(), handle);
+                    info!("{:?} [h:{}]", connection.stats(), handle);
                 }
-                log::info!("Exiting.");
+                info!("Exiting.");
                 exit.send(AppExit);
                 return;
             } else {
@@ -162,9 +163,9 @@ fn ttl_system(mut ttl: ResMut<TTL>, mut exit: EventWriter<AppExit>, time: Res<Ti
 }
 
 fn send_messages(
-    mut net: ResMut<NetworkResource>, 
-    mut ppc: ResMut<PingPongCounter>, 
-    args: Res<Args>, 
+    mut net: ResMut<NetworkResource>,
+    mut ppc: ResMut<PingPongCounter>,
+    args: Res<Args>,
     mut ttl: ResMut<TTL>,
     ticks: Res<Ticks>,
 ) {
@@ -177,7 +178,7 @@ fn send_messages(
         if ppc.pings_sent < NUM_PINGS {
             ppc.pings_sent += 1;
             let msg = NetMsg::Ping(ppc.pings_sent);
-            log::info!("[t:{}] Sending ping {}", *ticks, ppc.pings_sent);
+            info!("[t:{}] Sending ping {}", *ticks, ppc.pings_sent);
             net.broadcast_message(msg);
         } else if ppc.pings_sent == NUM_PINGS && ttl.is_none() {
             // shutdown after short delay, to finish receiving in-flight pongs
@@ -200,16 +201,16 @@ fn handle_messages(
             match netmsg {
                 NetMsg::Ping(i) => {
                     ppc.pings_seen += 1;
-                    log::info!("[t:{}] Sending pong {}", *ticks, i);
+                    info!("[t:{}] Sending pong {}", *ticks, i);
                     to_send.push((*handle, NetMsg::Pong(i)));
                     // seen our first ping, so schedule a shutdown
                     if ttl.is_none() {
                         *ttl = Some(3.0);
                     }
-                },
+                }
                 NetMsg::Pong(i) => {
                     ppc.pongs_seen += 1;
-                    log::info!("[t:{}] Got pong {}", *ticks, i);
+                    info!("[t:{}] Got pong {}", *ticks, i);
                 }
             }
         }
