@@ -1,37 +1,21 @@
-use bevy::{
-    app::{App, EventReader, ScheduleRunnerSettings},
-    core::Time,
-    ecs::prelude::*,
-    MinimalPlugins,
-};
+use bevy::{app::ScheduleRunnerSettings, log::LogPlugin, prelude::*};
 use bevy_networking_turbulence::{NetworkEvent, NetworkResource, NetworkingPlugin, Packet};
 
 use std::{net::SocketAddr, time::Duration};
 
 mod utils;
-use utils::{SimpleArgs as Args, parse_simple_args};
+use utils::{parse_simple_args, SimpleArgs as Args};
 
 const SERVER_PORT: u16 = 14191;
 
 fn main() {
-    cfg_if::cfg_if! {
-        if #[cfg(target_arch = "wasm32")] {
-            std::panic::set_hook(Box::new(console_error_panic_hook::hook));
-            console_log::init_with_level(log::Level::Debug).expect("cannot initialize console_log");
-        }
-        else {
-            simple_logger::SimpleLogger::from_env()
-            .init()
-            .expect("A logger was already initialized");
-        }
-    }
-
-    App::build()
+    App::new()
         // minimal plugins necessary for timers + headless loop
         .insert_resource(ScheduleRunnerSettings::run_loop(Duration::from_secs_f64(
             1.0 / 60.0,
         )))
         .add_plugins(MinimalPlugins)
+        .add_plugin(LogPlugin)
         // The NetworkingPlugin
         .add_plugin(NetworkingPlugin::default())
         // Our networking
@@ -59,11 +43,11 @@ fn startup(mut net: ResMut<NetworkResource>, args: Res<Args>) {
 
     #[cfg(not(target_arch = "wasm32"))]
     if args.is_server {
-        log::info!("Starting server");
+        info!("Starting server");
         net.listen(server_address, None, None);
     }
     if !args.is_server {
-        log::info!("Starting client");
+        info!("Starting client");
         net.connect(server_address);
     }
 }
@@ -71,7 +55,7 @@ fn startup(mut net: ResMut<NetworkResource>, args: Res<Args>) {
 fn send_packets(mut net: ResMut<NetworkResource>, time: Res<Time>, args: Res<Args>) {
     if !args.is_server {
         if (time.seconds_since_startup() * 60.) as i64 % 60 == 0 {
-            log::info!("PING");
+            info!("PING");
             net.broadcast(Packet::from("PING"));
         }
     }
@@ -85,15 +69,15 @@ fn handle_packets(
         match event {
             NetworkEvent::Packet(handle, packet) => {
                 let message = String::from_utf8_lossy(packet);
-                log::info!("Got packet on [{}]: {}", handle, message);
+                info!("Got packet on [{}]: {}", handle, message);
                 if message == "PING" {
                     let message = format!("PONG @ {}", time.seconds_since_startup());
                     match net.send(*handle, Packet::from(message)) {
                         Ok(()) => {
-                            log::info!("Sent PONG");
+                            info!("Sent PONG");
                         }
                         Err(error) => {
-                            log::info!("PONG send error: {}", error);
+                            info!("PONG send error: {}", error);
                         }
                     }
                 }
